@@ -1,4 +1,4 @@
-//$Id: radiobuttons.cc 449 2005-11-16 20:22:00Z  $ -*- c++ -*-
+//$Id: radiobuttons.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -27,40 +27,49 @@ RadioButtons::RadioButtons() :
   m_RadioButton3("button3"),
   m_Button_Close("close")
 {
+  // Set title and border of the window
   set_title("radio buttons");
   set_border_width(0);
 
-  //Put radio buttons 2 and 3 in the same group as 1:
+  // Put radio buttons 2 and 3 in the same group as 1:
   Gtk::RadioButton::Group group = m_RadioButton1.get_group();
   m_RadioButton2.set_group(group);
   m_RadioButton3.set_group(group);
 
+  // Add outer box to the window (because the window
+  // can only contain a single widget)
   add(m_Box_Top);
 
-  //Put Box1 in m_Box_Top:
-  m_Box1.set_border_width(10);
+  //Put the inner boxes and the separator in the outer box:
   m_Box_Top.pack_start(m_Box1);
+  m_Box_Top.pack_start(m_Separator);
+  m_Box_Top.pack_start(m_Box2);
 
-  //Put the radio buttons in Box1:
+  // Set the inner boxes' borders
+  m_Box2.set_border_width(10);
+  m_Box1.set_border_width(10);
+
+  // Put the radio buttons in Box1:
   m_Box1.pack_start(m_RadioButton1);
   m_Box1.pack_start(m_RadioButton2);
   m_Box1.pack_start(m_RadioButton3);
+
+  // Set the second button active
   m_RadioButton2.set_active();
 
-  //Add a separator:
-  m_Box_Top.pack_start(m_Separator, Gtk::PACK_SHRINK);
-
-  //Put Box2 in m_Box_Top:
-  m_Box2.set_border_width(10);
-  m_Box_Top.pack_start(m_Box2, Gtk::PACK_SHRINK);
-
-  //Put Close button in Box2:
+  // Put Close button in Box2:
   m_Box2.pack_start(m_Button_Close);
+
+  // Make the button the default widget
   m_Button_Close.set_flags(Gtk::CAN_DEFAULT);
   m_Button_Close.grab_default();
 
-  m_Button_Close.signal_clicked().connect( sigc::mem_fun(*this, &RadioButtons::on_button_clicked) );
+  // Connect the clicked signal of the button to
+  // RadioButtons::on_button_clicked()
+  m_Button_Close.signal_clicked().connect(sigc::mem_fun(*this,
+              &RadioButtons::on_button_clicked) );
 
+  // Show all children of the window
   show_all_children();
 }
 
