@@ -1,4 +1,4 @@
-//$Id: examplewindow.cc,v 1.3 2004/02/10 14:49:00 murrayc Exp $ -*- c++ -*-
+//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -24,10 +24,11 @@ ExampleWindow::ExampleWindow()
 : m_Button("sans")
 {
   set_title("Gtk::FontSelectionDialog example");
-  
-  add(m_Button);  
-  m_Button.signal_font_set().connect( sigc::mem_fun(*this, &ExampleWindow::on_button_font_set) );
-  
+
+  add(m_Button);
+  m_Button.signal_font_set().connect(sigc::mem_fun(*this,
+              &ExampleWindow::on_button_font_set) );
+
   show_all_children();
 }
 
