@@ -1,4 +1,4 @@
-//$Id: examplewindow.cc,v 1.7 2006/07/19 02:55:15 jjongsma Exp $ -*- c++ -*-
+//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -28,12 +28,14 @@ ExampleWindow::ExampleWindow()
   set_title("Gtk::MessageDialog example");
 
   add(m_ButtonBox);
-  
+
   m_ButtonBox.pack_start(m_Button_Info);
-  m_Button_Info.signal_clicked().connect( sigc::mem_fun(*this, &ExampleWindow::on_button_info_clicked) );
+  m_Button_Info.signal_clicked().connect(sigc::mem_fun(*this,
+              &ExampleWindow::on_button_info_clicked) );
 
   m_ButtonBox.pack_start(m_Button_Question);
-  m_Button_Question.signal_clicked().connect( sigc::mem_fun(*this, &ExampleWindow::on_button_question_clicked) );
+  m_Button_Question.signal_clicked().connect(sigc::mem_fun(*this,
+              &ExampleWindow::on_button_question_clicked) );
 
   show_all_children();
 }
@@ -45,15 +47,19 @@ ExampleWindow::~ExampleWindow()
 void ExampleWindow::on_button_info_clicked()
 {
   Gtk::MessageDialog dialog(*this, "This is an INFO MessageDialog");
-  dialog.set_secondary_text("And this is the secondary text that explains things.");
+  dialog.set_secondary_text(
+          "And this is the secondary text that explains things.");
 
   dialog.run();
 }
 
 void ExampleWindow::on_button_question_clicked()
 {
-  Gtk::MessageDialog dialog(*this, "This is a QUESTION MessageDialog", false /* use_markup */, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL);
-  dialog.set_secondary_text("And this is the secondary text that explains things.");
+  Gtk::MessageDialog dialog(*this, "This is a QUESTION MessageDialog",
+          false /* use_markup */, Gtk::MESSAGE_QUESTION,
+          Gtk::BUTTONS_OK_CANCEL);
+  dialog.set_secondary_text(
+          "And this is the secondary text that explains things.");
 
   int result = dialog.run();
 
@@ -76,5 +82,4 @@ void ExampleWindow::on_button_question_clicked()
       break;
     }
   }
-  
 }
