@@ -1,4 +1,4 @@
-//$Id: examplewindow.cc 858 2007-06-22 08:37:15Z murrayc $ -*- c++ -*-
+//$Id: examplewindow.cc 969 2008-02-23 18:39:51Z murrayc $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -17,8 +17,13 @@
  */
 
 #include <iostream>
+#include <cstdio>
+#include <cstdlib>
 #include "examplewindow.h"
 
+using std::sprintf;
+using std::strtol;
+
 ExampleWindow::ExampleWindow()
 : m_Button_Quit("Quit"),
   m_validate_retry(false)
