@@ -1,4 +1,4 @@
-//$Id: calendar.cc 705 2006-07-19 02:55:32Z jjongsma $ -*- c++ -*-
+//$Id: calendar.cc 829 2007-05-01 17:04:39Z murrayc $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -265,11 +265,10 @@ CalendarExample::CalendarExample()
 Glib::Date CalendarExample::get_date() const
 {
   using Glib::Date;
-
-  unsigned int year = 0, month = 0, day = 0;
-  calendar_->get_date(year, month, day);
-
-  return Date(Date::Day(day), Date::Month(Date::JANUARY + month), Date::Year(year));
+  Date date;
+  calendar_->get_date(date);
+  
+  return date;  
 }
 
 
